@@ -53,7 +53,7 @@ sub EXT_override_field_Display : Override('Ext.field.Display') {
 sub EXT_override_grid_plugin_ViewOptions : Override('Ext.grid.plugin.ViewOptions') {
     return {
         onColumnAdd => func [ 'grid', 'column' ],
-        <<~'JS',
+        <<'JS',
             var text = column.getText();
 
             if (Ext.isObject(text)) {
